# -*- coding: utf-8 -*-
"""
filtering package.
"""

from pyrin.packaging.base import Package


class FilteringPackage(Package):
    """
    filtering package class.
    """

    NAME = __name__
    COMPONENT_NAME = 'filtering.component'
