# -*- coding: utf-8 -*-
"""
utilities range package.
"""

from pyrin.packaging.base import Package


class UtilitiesRangePackage(Package):
    """
    utilities range package class.
    """

    NAME = __name__
    COMPONENT_NAME = 'utilities.range.component'
