# -*- coding: utf-8 -*-
"""
swagger tags package.
"""

from pyrin.packaging.base import Package


class SwaggerTagsPackage(Package):
    """
    swagger tags package class.
    """

    NAME = __name__
